tests.metadata package
======================

.. automodule:: tests.metadata
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::

   tests.metadata.test_roundtrips

